[Intel-gfx] [PATCH 1/2] drm: Export drm_create_file_anon()

Chris Wilson chris at chris-wilson.co.uk
Wed Jan 1 12:17:16 UTC 2020


Signed-off-by: Chris Wilson <chris at chris-wilson.co.uk>
---
 drivers/gpu/drm/drm_file.c                | 6 +++---
 drivers/gpu/drm/i915/selftests/igt_mmap.c | 2 +-
 drivers/gpu/drm/i915/selftests/mock_drm.h | 2 +-
 include/drm/drm_file.h                    | 2 +-
 4 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/gpu/drm/i915/selftests/igt_mmap.c b/drivers/gpu/drm/i915/selftests/igt_mmap.c
index 583a4ff8b8c9..c84f2a0b481a 100644
--- a/drivers/gpu/drm/i915/selftests/igt_mmap.c
+++ b/drivers/gpu/drm/i915/selftests/igt_mmap.c
@@ -19,7 +19,7 @@ unsigned long igt_mmap_node(struct drm_i915_private *i915,
 	int err;
 
 	/* Pretend to open("/dev/dri/card0") */
-	file = mock_drm_getfile(i915->drm.primary, O_RDWR);
+	file = drm_file_create_anon(i915->drm.primary, O_RDWR);
 	if (IS_ERR(file))
 		return PTR_ERR(file);
 
diff --git a/drivers/gpu/drm/i915/selftests/mock_drm.h b/drivers/gpu/drm/i915/selftests/mock_drm.h
index 9916b6f95526..3797be7a3d24 100644
--- a/drivers/gpu/drm/i915/selftests/mock_drm.h
+++ b/drivers/gpu/drm/i915/selftests/mock_drm.h
@@ -34,7 +34,7 @@ struct file;
 
 static inline struct file *mock_file(struct drm_i915_private *i915)
 {
-	return mock_drm_getfile(i915->drm.primary, O_RDWR);
+	return drm_file_create_anon(i915->drm.primary, O_RDWR);
 }
 
 static inline struct drm_file *to_drm_file(struct file *f)
diff --git a/include/drm/drm_file.h b/include/drm/drm_file.h
index 8b099b347817..a373a79b4290 100644
--- a/include/drm/drm_file.h
+++ b/include/drm/drm_file.h
@@ -388,6 +388,6 @@ void drm_event_cancel_free(struct drm_device *dev,
 void drm_send_event_locked(struct drm_device *dev, struct drm_pending_event *e);
 void drm_send_event(struct drm_device *dev, struct drm_pending_event *e);
 
-struct file *mock_drm_getfile(struct drm_minor *minor, unsigned int flags);
+struct file *drm_file_create_anon(struct drm_minor *minor, unsigned int flags);
 
 #endif /* _DRM_FILE_H_ */
diff --git a/drivers/gpu/drm/drm_file.c b/drivers/gpu/drm/drm_file.c
index 92d16724f949..a3bcb773d363 100644
--- a/drivers/gpu/drm/drm_file.c
+++ b/drivers/gpu/drm/drm_file.c
@@ -758,7 +758,7 @@ void drm_send_event(struct drm_device *dev, struct drm_pending_event *e)
 EXPORT_SYMBOL(drm_send_event);
 
 /**
  * mock_drm_getfile - Create a new struct file for the drm device
  * @minor: drm minor to wrap (e.g. #drm_device.primary)
  * @flags: file creation mode (O_RDWR etc)
  *
@@ -771,7 +771,7 @@ EXPORT_SYMBOL(drm_send_event);
  * RETURNS:
  * Pointer to newly created struct file, ERR_PTR on failure.
  */
-struct file *mock_drm_getfile(struct drm_minor *minor, unsigned int flags)
+struct file *drm_file_create_anon(struct drm_minor *minor, unsigned int flags)
 {
 	struct drm_device *dev = minor->dev;
 	struct drm_file *priv;
@@ -795,4 +795,4 @@ struct file *mock_drm_getfile(struct drm_minor *minor, unsigned int flags)
 
 	return file;
 }
-EXPORT_SYMBOL_FOR_TESTS_ONLY(mock_drm_getfile);
+EXPORT_SYMBOL(drm_file_create_anon);
@@ -758,7 +758,7 @@ void drm_send_event(struct drm_device *dev, struct drm_pending_event *e)
 
 /**
- * mock_drm_getfile - Create a new struct file for the drm device
+ * drm_file_create_anon - Create a new struct file for the drm device
  * @minor: drm minor to wrap (e.g. #drm_device.primary)
  * @flags: file creation mode (O_RDWR etc)
-- 
2.25.0.rc0



More information about the Intel-gfx mailing list